==> datanucleus-core-3.2.10-sources.jar: org/datanucleus/management/FactoryStatisticsMBean.java <==
/**********************************************************************
Copyright (c) 2012 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.management;

/**
 * Interface defining the MBean for a persistence factory.
 */
public interface FactoryStatisticsMBean
{
    String getRegisteredName();

    int getQueryActiveTotalCount();

    int getQueryErrorTotalCount();

    int getQueryExecutionTotalCount();

    int getQueryExecutionTimeLow();

    int getQueryExecutionTimeHigh();

    int getQueryExecutionTotalTime();

    int getQueryExecutionTimeAverage();

    int getNumberOfDatastoreWrites();

    int getNumberOfDatastoreReads();

    int getNumberOfDatastoreWritesInLatestTxn();

    int getNumberOfDatastoreReadsInLatestTxn();

    int getNumberOfObjectFetches();

    int getNumberOfObjectInserts();

    int getNumberOfObjectUpdates();

    int getNumberOfObjectDeletes();

    int getTransactionExecutionTimeAverage();

    int getTransactionExecutionTimeLow();

    int getTransactionExecutionTimeHigh();

    int getTransactionExecutionTotalTime();

    int getTransactionTotalCount();

    int getTransactionActiveTotalCount();

    int getTransactionCommittedTotalCount();

    int getTransactionRolledBackTotalCount();

    int getConnectionActiveCurrent();

    int getConnectionActiveHigh();

    int getConnectionActiveTotal();
}

==> datanucleus-core-5.2.3-sources.jar: org/datanucleus/management/FactoryStatisticsMBean.java <==
/**********************************************************************
Copyright (c) 2012 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.management;

/**
 * Interface defining the MBean for a persistence factory.
 */
public interface FactoryStatisticsMBean
{
    String getRegisteredName();

    int getQueryActiveTotalCount();

    int getQueryErrorTotalCount();

    int getQueryExecutionTotalCount();

    long getQueryExecutionTimeLow();

    long getQueryExecutionTimeHigh();

    long getQueryExecutionTotalTime();

    long getQueryExecutionTimeAverage();

    int getNumberOfDatastoreWrites();

    int getNumberOfDatastoreReads();

    int getNumberOfDatastoreWritesInLatestTxn();

    int getNumberOfDatastoreReadsInLatestTxn();

    int getNumberOfObjectFetches();

    int getNumberOfObjectInserts();

    int getNumberOfObjectUpdates();

    int getNumberOfObjectDeletes();

    long getTransactionExecutionTimeAverage();

    long getTransactionExecutionTimeLow();

    long getTransactionExecutionTimeHigh();

    long getTransactionExecutionTotalTime();

    int getTransactionTotalCount();

    int getTransactionActiveTotalCount();

    int getTransactionCommittedTotalCount();

    int getTransactionRolledBackTotalCount();

    int getConnectionActiveCurrent();

    int getConnectionActiveHigh();

    int getConnectionActiveTotal();
}
